### Name: zicounts
### Title: Fitting classical and zero-inflated count regression models
### Aliases: zicounts
### Keywords: models

### ** Examples

## load the artificial 'teeth' data
 data(teeth)
 names(teeth)
  
## a) fit a Poisson regression model
pois.zc1 <- zicounts(parm=c(-2,-2,1),resp = dmft~.,x =~gender + age, data=teeth, distr = "Poisson")
pois.zc1 # starting values specified

pois.zc2 <- zicounts(resp = dmft~.,x =~gender + age, data=teeth, distr = "Poisson")
pois.zc2 # starting values estimated from data

# compare with glm
pois.glm <- glm(dmft~gender + age, family=poisson,data=teeth)
pois.glm

# fit for boys only -- using 'sub'
pois.girl <- zicounts(resp = dmft~.,x =~age, data=teeth, distr = "Poisson",sub=expression(gender==0))
pois.girl # starting values estimated from data

# Poisson with offset
pois.zc3 <- zicounts(resp = dmft~.,x =~gender + age, offset= expression(log(decid + 1)), data=teeth, distr = "Poisson")
pois.zc3

# compare with glm
pois.glm2 <- glm(dmft~gender + age, offset= log(decid + 1), family=poisson,data=teeth)
pois.glm2  

## b) fit zero-inflated  Poisson regression model
zip.zc <- zicounts(resp = dmft~.,x =~gender + age,z =~gender + age, data=teeth, distr = "ZIP")
zip.zc
#summary(zip.zc)

## c) fit negative binomial regression model
nb.zc <- zicounts(resp = dmft~.,x =~gender + age,data=teeth, distr = "NB")
nb.zc
#summary(nb.zc)

## d) fit zero-inflated negative binomial regression model
zinb.zc <- zicounts(resp = dmft~.,x =~gender + age,z =~gender + age, data=teeth)
zinb.zc
#summary(zinb.zc)



